@@ -1,7 +1,7 @@
 from django.db import models
 # Create your models here.
 
-import caching
+import caching.base
 
 class Orthography(models.Model):
     word = models.CharField(max_length = 250,unique=True)
