@@ -17,6 +17,7 @@ def reset_trigrams():
         load_trigram_file(f)
 
 def delete_all():
+    Orthography.objects.all().delete()
     Trigram.objects.all().delete()
 
 def load_trigram_file(f):
@@ -24,7 +25,9 @@ def load_trigram_file(f):
     with open(os.path.join(settings.TRIGRAM_PATH,f),'r') as file_handle:
         for line in file_handle:
             l = line.strip().split("\t")
-            words = l[0].split(" ")
+            words = []
+            for w in l[0].split(" "):
+                words.append(Orthography.objects.get_or_create(word=w)[0])
             trgs.append(Trigram(word=words[-1],word_i_minus_one=words[1],word_i_minus_two=words[0],count=int(l[1])))
             if len(trgs) > 100000:
                 Trigram.objects.bulk_create(trgs)
